==> haskell-servant-server-0.20.3.0-56-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-server
version:              0.20.3.0
visibility:           public
id:                   servant-server-0.20.3.0-E3FmgvagBLoLb2imcYU7r6
key:                  servant-server-0.20.3.0-E3FmgvagBLoLb2imcYU7r6
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  af0f960476a8831fb35a235184ce72b1
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.ErrorFormatter
    Servant.Server.Internal.Handler
    Servant.Server.Internal.ResponseRender
    Servant.Server.Internal.RouteResult Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Server.UVerb Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-server-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-server-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-server-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-server
hs-libraries:         HSservant-server-0.20.3.0-E3FmgvagBLoLb2imcYU7r6
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
    bytestring-0.11.5.3 constraints-0.14.2-5Hasiz3qGyu5OkYwKIAmXY
    containers-0.6.7 exceptions-0.10.7 filepath-1.4.300.1
    http-api-data-0.6.1-5XEHPNAfLnyD0ajpwpE9eT
    http-media-0.8.1.1-IVN9WTR9Vpq260gzanGeUu
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx
    servant-0.20.3.0-FMI4LG4x1t4Dir4ovtxFzm
    sop-core-0.5.0.2-1KOi1hjK2a7LcGI7gMT7tS
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    wai-3.2.4-DrO6v22Rmno6pXUhKStSuj
    wai-app-static-3.1.9-4uOIlQH3zdpA3ZlOly7mj8
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.20.3.0-58-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-server
version:              0.20.3.0
visibility:           public
id:                   servant-server-0.20.3.0-7va9YCS8eTU5H3qTaWEilz
key:                  servant-server-0.20.3.0-7va9YCS8eTU5H3qTaWEilz
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  d608821a142e23eec2988f35cf152c37
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.ErrorFormatter
    Servant.Server.Internal.Handler
    Servant.Server.Internal.ResponseRender
    Servant.Server.Internal.RouteResult Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Server.UVerb Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-server-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-server-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-server-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-server
hs-libraries:         HSservant-server-0.20.3.0-7va9YCS8eTU5H3qTaWEilz
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 constraints-0.14.2-HITsp0guL9Z2vC96u1IEz
    containers-0.6.7 exceptions-0.10.7 filepath-1.4.300.1
    http-api-data-0.6.1-6b8SlzeGz22trXyYobem
    http-media-0.8.1.1-ESBCw4Dvl5R7GQFVDBq0Rc
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs
    servant-0.20.3.0-EGizVGIAZ794yRWvR5V6rz
    sop-core-0.5.0.2-1KOi1hjK2a7LcGI7gMT7tS
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
    wai-app-static-3.1.9-5YuV7YlKgoJECZOZIgHDZ
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
